==> cockpit-podman-21-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.de.js <==
(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "de",
  "x-generator": "Weblate 3.9.1"
 },
 "Are you sure you want to delete this image?": [
  null,
  "Sind Sie sicher, dass Sie dieses Image löschen wollen?"
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Podman automatisch beim Hochfahren starten"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU Shares": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Abbruch"
 ],
 "Command": [
  null,
  "Befehl"
 ],
 "Commit": [
  null,
  "Committen"
 ],
 "Commit Image": [
  null,
  "Image committen"
 ],
 "Console": [
  null,
  "Konsole"
 ],
 "Container Name": [
  null,
  "Container-Name"
 ],
 "Container failed to be created": [
  null,
  "Container konnte nicht erstellt werden"
 ],
 "Container is currently running.": [
  null,
  "Container läuft gerade."
 ],
 "Container is not running": [
  null,
  "Container läuft nicht"
 ],
 "Container path": [
  null,
  "Container-Pfad"
 ],
 "Container port": [
  null,
  "Container-Port"
 ],
 "Containers": [
  null,
  "Container"
 ],
 "Could not attach to this container: $0": [
  null,
  "Konnte nicht mit diesem Container verbinden: $0"
 ],
 "Could not open channel: $0": [
  null,
  "Konnte keinen Kanal öffnen: $0"
 ],
 "Created": [
  null,
  "Erstellt"
 ],
 "Delete": [
  null,
  "Löschen"
 ],
 "Delete $0": [
  null,
  "$0 löschen"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Beim Löschen des Containers werden alle Daten darin verloren gehen."
 ],
 "Details": [
  null,
  "Details"
 ],
 "Download": [
  null,
  "Herunterladen"
 ],
 "Download as:": [
  null,
  "Herunterladen als:"
 ],
 "Entrypoint": [
  null,
  "Einsprungspunkt"
 ],
 "Environment": [
  null,
  "Umgebung"
 ],
 "Error message": [
  null,
  "Fehlermeldung"
 ],
 "Everything": [
  null,
  "Alles"
 ],
 "Exited": [
  null,
  "Beendet"
 ],
 "Failed to commit container $0": [
  null,
  "Konnte Container $0 nicht committen"
 ],
 "Failed to download image $0:$1": [
  null,
  "Konnte Image $0 nicht herunterladen: $1"
 ],
 "Failed to force remove container $0": [
  null,
  ""
 ],
 "Failed to remove container $0": [
  null,
  "Konnte Container $0 nicht neu entfernen"
 ],
 "Failed to restart container $0": [
  null,
  "Konnte Container $0 nicht neu starten"
 ],
 "Failed to search for new images": [
  null,
  "Konnte nicht nach neuen Images suchen"
 ],
 "Failed to start container $0": [
  null,
  "Konnte Container $0 nicht starten"
 ],
 "Failed to stop container $0": [
  null,
  "Konnte Container $0 nicht stoppen"
 ],
 "Force Delete": [
  null,
  "Löschen erzwingen"
 ],
 "Force Restart": [
  null,
  "Neustart erzwingen"
 ],
 "Force Stop": [
  null,
  "Stoppen erzwingen"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Get new image": [
  null,
  "Neues Image herunterladen"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Host path": [
  null,
  ""
 ],
 "Host port": [
  null,
  ""
 ],
 "ID": [
  null,
  "ID"
 ],
 "Image": [
  null,
  "Image"
 ],
 "Image Name": [
  null,
  "Image-Name"
 ],
 "Images": [
  null,
  "Images"
 ],
 "Images and running containers": [
  null,
  "Images und laufende Container"
 ],
 "Key": [
  null,
  "Schlüssel"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Loading...": [
  null,
  "Lade..."
 ],
 "Memory": [
  null,
  "Speicher"
 ],
 "Memory Limit": [
  null,
  "Speicher-Limit"
 ],
 "Message": [
  null,
  "Nachricht"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Name": [
  null,
  "Name"
 ],
 "No containers": [
  null,
  "Keine Container"
 ],
 "No containers are using this image": [
  null,
  "Kein Container benutzt dieses Image"
 ],
 "No containers that match the current filter": [
  null,
  "Aktueller Filter passt auf keinen Container"
 ],
 "No images": [
  null,
  "Keine Images"
 ],
 "No images that match the current filter": [
  null,
  "Aktueller Filter passt auf kein Image"
 ],
 "No results for $0. Please retry another term.": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Keine laufenden Container"
 ],
 "On Build": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Eigentümer"
 ],
 "Pause": [
  null,
  "Anhalten"
 ],
 "Pause the container": [
  null,
  "Den Container anhalten"
 ],
 "Please confirm deletion of $0": [
  null,
  "Bitte bestätigen Sie das Löschen von $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Bitte bestätigen Sie das erzwungene Löschen von $0"
 ],
 "Podman Containers": [
  null,
  "Podman-Container"
 ],
 "Podman Service is Not Active": [
  null,
  "Podman-Service ist nicht aktiv"
 ],
 "Ports": [
  null,
  "Ports"
 ],
 "Pulling": [
  null,
  "Herunterladen"
 ],
 "ReadOnly": [
  null,
  "Nur lesen"
 ],
 "ReadWrite": [
  null,
  "Lesen und Schreiben"
 ],
 "Restart": [
  null,
  "Neustart"
 ],
 "Run": [
  null,
  "Starten"
 ],
 "Run Image": [
  null,
  "Image starten"
 ],
 "Search Image": [
  null,
  "Image suchen"
 ],
 "Search by name or description": [
  null,
  "Nach Name oder Beschreibung suchen"
 ],
 "Security": [
  null,
  "Sicherheit"
 ],
 "Set container on build variables": [
  null,
  ""
 ],
 "Size": [
  null,
  "Größe"
 ],
 "Start": [
  null,
  "Starten"
 ],
 "Start podman": [
  null,
  "Podman starten"
 ],
 "State": [
  null,
  "Zustand"
 ],
 "Stop": [
  null,
  "Stoppen"
 ],
 "System": [
  null,
  "System"
 ],
 "System Podman service is also available": [
  null,
  "System-Podman ist auch verfügbar"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etikett"
 ],
 "Tags": [
  null,
  "Etiketten"
 ],
 "The scan from $time ($type) found no vulnerabilities.": [
  null,
  ""
 ],
 "This version of the Web Console does not support a terminal.": [
  null,
  "Diese Version der Web-Konsole unterstützt kein Terminal."
 ],
 "Troubleshoot": [
  null,
  "Fehler suchen"
 ],
 "Type to filter…": [
  null,
  "Tippen zum filtern…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Läuft seit $0"
 ],
 "Used By": [
  null,
  "Benutzt von"
 ],
 "User Podman service is also available": [
  null,
  "Benutzer-Podman ist auch verfügbar"
 ],
 "Value": [
  null,
  "Wert"
 ],
 "Volumes": [
  null,
  ""
 ],
 "With terminal": [
  null,
  "Mit Terminal"
 ],
 "n/a": [
  null,
  "n.v."
 ],
 "not available": [
  null,
  "nicht verfügbar"
 ],
 "system": [
  null,
  "System"
 ],
 "user": [
  null,
  "Benutzer"
 ]
}));

==> cockpit-podman-24-1-x86_64.pkg.tar.zst: usr/share/cockpit/podman/po.de.js <==
(function (root, data) {
    var loaded, module;

    /* Load into Cockpit locale */
    if (typeof cockpit === 'object') {
        cockpit.locale(data)
        loaded = true;
    }

    if (!loaded)
        root.po = data;

/* The syntax of this line is important  by po2json */
}(this, {
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n != 1;
return plural;
},
  "language": "de",
  "x-generator": "Weblate 3.9.1"
 },
 "Add item": [
  null,
  ""
 ],
 "Add on build variable": [
  null,
  ""
 ],
 "All": [
  null,
  ""
 ],
 "All registries": [
  null,
  ""
 ],
 "An error occured": [
  null,
  ""
 ],
 "Author": [
  null,
  "Autor"
 ],
 "Automatically start podman on boot": [
  null,
  "Podman automatisch beim Hochfahren starten"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU shares": [
  null,
  ""
 ],
 "Cancel": [
  null,
  "Abbruch"
 ],
 "Checkpoint": [
  null,
  ""
 ],
 "Checkpoint container $0": [
  null,
  "Konnte Container $0 nicht committen"
 ],
 "Command": [
  null,
  "Befehl"
 ],
 "Commit": [
  null,
  "Committen"
 ],
 "Commit image": [
  null,
  "Image committen"
 ],
 "Console": [
  null,
  "Konsole"
 ],
 "Container": [
  null,
  "Container"
 ],
 "Container failed to be created": [
  null,
  "Container konnte nicht erstellt werden"
 ],
 "Container failed to be started": [
  null,
  "Container konnte nicht erstellt werden"
 ],
 "Container is currently running.": [
  null,
  "Container läuft gerade."
 ],
 "Container is not running": [
  null,
  "Container läuft nicht"
 ],
 "Container name": [
  null,
  "Container-Name"
 ],
 "Container path": [
  null,
  "Container-Pfad"
 ],
 "Container port": [
  null,
  "Container-Port"
 ],
 "Containers": [
  null,
  "Container"
 ],
 "Created": [
  null,
  "Erstellt"
 ],
 "Delete": [
  null,
  "Löschen"
 ],
 "Delete $0": [
  null,
  "$0 löschen"
 ],
 "Delete image": [
  null,
  "Neues Image herunterladen"
 ],
 "Delete tagged images": [
  null,
  "Neues Image herunterladen"
 ],
 "Deleting a container will erase all data in it.": [
  null,
  "Beim Löschen des Containers werden alle Daten darin verloren gehen."
 ],
 "Deleting this pod will remove the following containers:": [
  null,
  ""
 ],
 "Details": [
  null,
  "Details"
 ],
 "Do not include root file-system changes when exporting": [
  null,
  ""
 ],
 "Download": [
  null,
  "Herunterladen"
 ],
 "Entrypoint": [
  null,
  "Einsprungspunkt"
 ],
 "Environment": [
  null,
  "Umgebung"
 ],
 "Error": [
  null,
  ""
 ],
 "Error message": [
  null,
  "Fehlermeldung"
 ],
 "Exited": [
  null,
  "Beendet"
 ],
 "Failed to checkpoint container $0": [
  null,
  "Konnte Container $0 nicht committen"
 ],
 "Failed to commit container $0": [
  null,
  "Konnte Container $0 nicht committen"
 ],
 "Failed to download image $0:$1": [
  null,
  "Konnte Image $0 nicht herunterladen: $1"
 ],
 "Failed to force remove container $0": [
  null,
  ""
 ],
 "Failed to force stop pod $0": [
  null,
  "Konnte Container $0 nicht stoppen"
 ],
 "Failed to pause pod $0": [
  null,
  "Konnte Container $0 nicht neu starten"
 ],
 "Failed to remove container $0": [
  null,
  "Konnte Container $0 nicht neu entfernen"
 ],
 "Failed to restart container $0": [
  null,
  "Konnte Container $0 nicht neu starten"
 ],
 "Failed to restart pod $0": [
  null,
  "Konnte Container $0 nicht neu starten"
 ],
 "Failed to restore container $0": [
  null,
  "Konnte Container $0 nicht neu starten"
 ],
 "Failed to resume pod $0": [
  null,
  "Konnte Container $0 nicht neu entfernen"
 ],
 "Failed to search for images: $0": [
  null,
  "Konnte nicht nach neuen Images suchen"
 ],
 "Failed to search for new images": [
  null,
  "Konnte nicht nach neuen Images suchen"
 ],
 "Failed to start container $0": [
  null,
  "Konnte Container $0 nicht starten"
 ],
 "Failed to start pod $0": [
  null,
  "Konnte Container $0 nicht starten"
 ],
 "Failed to stop container $0": [
  null,
  "Konnte Container $0 nicht stoppen"
 ],
 "Failed to stop pod $0": [
  null,
  "Konnte Container $0 nicht stoppen"
 ],
 "Force delete": [
  null,
  "Löschen erzwingen"
 ],
 "Force restart": [
  null,
  "Neustart erzwingen"
 ],
 "Force stop": [
  null,
  "Stoppen erzwingen"
 ],
 "Format": [
  null,
  "Format"
 ],
 "Gateway": [
  null,
  ""
 ],
 "Get new image": [
  null,
  "Neues Image herunterladen"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Hide intermediate images": [
  null,
  ""
 ],
 "Host path": [
  null,
  ""
 ],
 "Host port": [
  null,
  ""
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  ""
 ],
 "IP prefix length": [
  null,
  ""
 ],
 "Ignore IP address if set statically": [
  null,
  ""
 ],
 "Ignore MAC address if set statically": [
  null,
  ""
 ],
 "Image": [
  null,
  "Image"
 ],
 "Image name": [
  null,
  "Image-Name"
 ],
 "Images": [
  null,
  "Images"
 ],
 "Keep all temporary checkpoint files": [
  null,
  ""
 ],
 "Key": [
  null,
  "Schlüssel"
 ],
 "KiB": [
  null,
  "KiB"
 ],
 "Leave running after writing checkpoint to disk": [
  null,
  ""
 ],
 "Loading logs...": [
  null,
  "Lade..."
 ],
 "Loading...": [
  null,
  "Lade..."
 ],
 "Logs": [
  null,
  ""
 ],
 "MAC address": [
  null,
  ""
 ],
 "Memory": [
  null,
  "Speicher"
 ],
 "Memory limit": [
  null,
  "Speicher-Limit"
 ],
 "Message": [
  null,
  "Nachricht"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Multiple tags exist for this image. Select the tagged images to delete.": [
  null,
  ""
 ],
 "Name": [
  null,
  "Name"
 ],
 "No SELinux label": [
  null,
  ""
 ],
 "No containers": [
  null,
  "Keine Container"
 ],
 "No containers are using this image": [
  null,
  "Kein Container benutzt dieses Image"
 ],
 "No containers in this pod": [
  null,
  "Kein Container benutzt dieses Image"
 ],
 "No containers that match the current filter": [
  null,
  "Aktueller Filter passt auf keinen Container"
 ],
 "No images": [
  null,
  "Keine Images"
 ],
 "No images that match the current filter": [
  null,
  "Aktueller Filter passt auf kein Image"
 ],
 "No results for $0. Please retry another term.": [
  null,
  ""
 ],
 "No running containers": [
  null,
  "Keine laufenden Container"
 ],
 "On build": [
  null,
  ""
 ],
 "Only running": [
  null,
  ""
 ],
 "Owner": [
  null,
  "Eigentümer"
 ],
 "Pause": [
  null,
  "Anhalten"
 ],
 "Pause the container": [
  null,
  "Den Container anhalten"
 ],
 "Paused": [
  null,
  "Anhalten"
 ],
 "Please confirm deletion of $0": [
  null,
  "Bitte bestätigen Sie das Löschen von $0"
 ],
 "Please confirm deletion of pod $0": [
  null,
  "Bitte bestätigen Sie das Löschen von $0"
 ],
 "Please confirm force deletion of pod $0": [
  null,
  "Bitte bestätigen Sie das erzwungene Löschen von $0"
 ],
 "Please confirm forced deletion of $0": [
  null,
  "Bitte bestätigen Sie das erzwungene Löschen von $0"
 ],
 "Podman containers": [
  null,
  "Podman-Container"
 ],
 "Podman service is not active": [
  null,
  "Podman-Service ist nicht aktiv"
 ],
 "Ports": [
  null,
  "Ports"
 ],
 "Private": [
  null,
  ""
 ],
 "Pulling": [
  null,
  "Herunterladen"
 ],
 "ReadOnly": [
  null,
  "Nur lesen"
 ],
 "ReadWrite": [
  null,
  "Lesen und Schreiben"
 ],
 "Remove item": [
  null,
  ""
 ],
 "Remove on build variable": [
  null,
  ""
 ],
 "Restart": [
  null,
  "Neustart"
 ],
 "Restore": [
  null,
  "Neustart"
 ],
 "Restore container $0": [
  null,
  "Konnte Container $0 nicht neu entfernen"
 ],
 "Restore with established TCP connections": [
  null,
  ""
 ],
 "Resume": [
  null,
  ""
 ],
 "Run": [
  null,
  "Starten"
 ],
 "Run image": [
  null,
  "Image starten"
 ],
 "Running": [
  null,
  ""
 ],
 "Search by name or description": [
  null,
  "Nach Name oder Beschreibung suchen"
 ],
 "Search for": [
  null,
  "Image suchen"
 ],
 "Search for an image": [
  null,
  "Image suchen"
 ],
 "Set container on build variables": [
  null,
  ""
 ],
 "Shared": [
  null,
  ""
 ],
 "Show": [
  null,
  ""
 ],
 "Show intermediate images": [
  null,
  ""
 ],
 "Size": [
  null,
  "Größe"
 ],
 "Start": [
  null,
  "Starten"
 ],
 "Start podman": [
  null,
  "Podman starten"
 ],
 "State": [
  null,
  "Zustand"
 ],
 "Stop": [
  null,
  "Stoppen"
 ],
 "Stopped": [
  null,
  "Stoppen"
 ],
 "Support preserving established TCP connections": [
  null,
  ""
 ],
 "System": [
  null,
  "System"
 ],
 "System Podman service is also available": [
  null,
  "System-Podman ist auch verfügbar"
 ],
 "TCP": [
  null,
  "TCP"
 ],
 "Tag": [
  null,
  "Etikett"
 ],
 "Tags": [
  null,
  "Etiketten"
 ],
 "Troubleshoot": [
  null,
  "Fehler suchen"
 ],
 "Type to filter…": [
  null,
  "Tippen zum filtern…"
 ],
 "UDP": [
  null,
  "UDP"
 ],
 "Up since $0": [
  null,
  "Läuft seit $0"
 ],
 "Used by": [
  null,
  "Benutzt von"
 ],
 "User": [
  null,
  ""
 ],
 "User Podman service is also available": [
  null,
  "Benutzer-Podman ist auch verfügbar"
 ],
 "Value": [
  null,
  "Wert"
 ],
 "Volumes": [
  null,
  ""
 ],
 "With terminal": [
  null,
  "Mit Terminal"
 ],
 "configured": [
  null,
  ""
 ],
 "container": [
  null,
  "Container"
 ],
 "created": [
  null,
  "Erstellt"
 ],
 "exited": [
  null,
  "Beendet"
 ],
 "image": [
  null,
  "Image"
 ],
 "in": [
  null,
  ""
 ],
 "n/a": [
  null,
  "n.v."
 ],
 "not available": [
  null,
  "nicht verfügbar"
 ],
 "paused": [
  null,
  "Anhalten"
 ],
 "pod group": [
  null,
  ""
 ],
 "podman": [
  null,
  "Podman starten"
 ],
 "removing": [
  null,
  ""
 ],
 "running": [
  null,
  ""
 ],
 "select all": [
  null,
  ""
 ],
 "stopped": [
  null,
  ""
 ],
 "system": [
  null,
  "System"
 ],
 "user": [
  null,
  "Benutzer"
 ]
}));
